==> jc-1.4.0.tar.gz: soot/shimple/toolkits/scalar/ShimpleLocalDefs.h <==
// public class soot.shimple.toolkits.scalar.ShimpleLocalDefs

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 58a67d739c50c817 soot_shimple_toolkits_scalar_ShimpleLocalDefs

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_toolkits_scalar_ShimpleLocalDefs_H_
#define _JC_soot_shimple_toolkits_scalar_ShimpleLocalDefs_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Local$object;
struct _jc_soot_Unit$object;
struct _jc_soot_shimple_ShimpleBody$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_refs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$refs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$nonrefs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object;

typedef const struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vmethods	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtable	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtype	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtype;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$method$_init$c808cb4dc246b024(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object *, struct _jc_soot_shimple_ShimpleBody$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$method$getDefsOf$5af55721c9bfa9ed(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$method$getDefsOfAt$e4de57a6e143de4b(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object *, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$method_info$getDefsOf$5af55721c9bfa9ed;
extern _jc_method _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$method_info$getDefsOfAt$e4de57a6e143de4b;

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vmethods {
	struct _jc_object	*(*getDefsOf$5af55721c9bfa9ed)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object *, struct _jc_object *);
	struct _jc_object	*(*getDefsOfAt$e4de57a6e143de4b)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object *, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vmethods	soot_shimple_toolkits_scalar_ShimpleLocalDefs;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_refs {
	struct _jc_object	*localToDefs;
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$refs {
    _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_refs	soot_shimple_toolkits_scalar_ShimpleLocalDefs;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_nonrefs	soot_shimple_toolkits_scalar_ShimpleLocalDefs;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object {
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtype _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_ShimpleLocalDefs, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_ShimpleLocalDefs_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/toolkits/scalar/ShimpleLocalDefs.h <==
// public class soot.shimple.toolkits.scalar.ShimpleLocalDefs

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 58a67d739c50c817 soot_shimple_toolkits_scalar_ShimpleLocalDefs

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_toolkits_scalar_ShimpleLocalDefs_H_
#define _JC_soot_shimple_toolkits_scalar_ShimpleLocalDefs_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Local$object;
struct _jc_soot_Unit$object;
struct _jc_soot_shimple_ShimpleBody$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_refs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$refs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$nonrefs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object;

typedef const struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vmethods	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtable	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtype	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtype;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$method$_init$c808cb4dc246b024(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object *, struct _jc_soot_shimple_ShimpleBody$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$method$getDefsOf$5af55721c9bfa9ed(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$method$getDefsOfAt$e4de57a6e143de4b(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$method_info$getDefsOf$5af55721c9bfa9ed;
extern _jc_method _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$method_info$getDefsOfAt$e4de57a6e143de4b;

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vmethods {
	struct _jc_object	*(*getDefsOf$5af55721c9bfa9ed)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getDefsOfAt$e4de57a6e143de4b)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vmethods	soot_shimple_toolkits_scalar_ShimpleLocalDefs;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_refs {
	struct _jc_object	*localToDefs;
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$refs {
    _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_refs	soot_shimple_toolkits_scalar_ShimpleLocalDefs;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$sub_nonrefs	soot_shimple_toolkits_scalar_ShimpleLocalDefs;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$object {
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$vtype _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_ShimpleLocalDefs, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_ShimpleLocalDefs$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_ShimpleLocalDefs_H_ */
